static const char *keymenu=NULL;

PUBLIC void MODULE_MODULEN::setmenu (
	DIALOG &dia,
	MENU_CONTEXT context)
{
	if (context == MENUID){
		keymenu = MSG_U(M_MODULEN,"MENUTITLE");
		dia.new_menuitem ("MODULEN","",keymenu);
	}
}

PUBLIC int MODULE_MODULEN::domenu (
	MENU_CONTEXT context,
	const char *key)
{
	if (context == MENUID){
		if (key == keymenu){
			CONTEXT_LOCK l("MODULEN");
			if (l.isok()){
				// ### Place the call to the edit function here
			}
		}
	}
	return 0;
}

